@@ -1,5 +1,5 @@
-""" Simple IRC module
-"""
+#!/usr/bin/env python
+"""Simple IRC module"""
 
 import re
 from socket import socket, AF_INET6, AF_INET, SOCK_STREAM
@@ -8,21 +8,19 @@ from select import select
 from token_bucket import TokenBucketBuffer
 
 class IRCError(Exception):
-    """ Base class for all IRC related exceptions.
-    """
+    """Base class for all IRC related exceptions."""
 
 class InvalidIRCData(IRCError):
-    """ Raised when the passed data wasn't parsed because of structural
-        invalidation.
+    """Raised when the passed data wasn't parsed because of structural
+    invalidation.
     """
 
 class Disconnected(IRCError):
-    """ Raised when the socket is disconnected.
-    """
+    """Raised when the socket is disconnected."""
 
 class ModeArgumentError(IRCError):
-    """ Raised when an invalid number of arguments was passed to a mode
-        function.
+    """Raised when an invalid number of arguments was passed to a mode
+    function.
     """
 
 class IRCHostmask(object):
@@ -59,8 +57,7 @@ class IRCHostmask(object):
         return cmp(str(self), o)
 
 class IRCConnection(object):
-    """ Main IRC connection, subclassable.
-    """
+    """Main IRC connection, subclassable."""
 
     use_ipv6 = False
     irc_line_prefixed = re.compile(r'^:([^ ]+) (.*)$')
@@ -68,11 +65,11 @@ class IRCConnection(object):
 
     def __init__(self, remote_address=None, nickname=None, username=None,
             password=None, realname=None, local_address=None):
-        """ Construct an IRCConnection object.
+        """Construct an IRCConnection object.
 
-            remote_address must be a tuple of format (addr, port).
-            nickname, username and realname are for convenience with
-            IRCConnection.register.
+        remote_address must be a tuple of format (addr, port).
+        nickname, username and realname are for convenience with
+        IRCConnection.register.
         """
 
         self.process = False
@@ -85,6 +82,8 @@ class IRCConnection(object):
         self.in_buffer = ""
 
     def connect(self, remote_address, local_address=None):
+        """Connect to IRC server."""
+
         self.socket = socket((AF_INET, AF_INET6)[int(self.use_ipv6)], SOCK_STREAM)
         self.out_tbb = TokenBucketBuffer(
             max_size=3,
@@ -95,8 +94,7 @@ class IRCConnection(object):
             self.socket.bind(local_address)
     
     def register(self):
-        """ Convenience function for sending registration data.
-        """
+        """Convenience function for sending registration data."""
 
         self.send("NICK :%s\n" % (self.nickname,))
         self.send("USER %s 0 0 :%s\n" % (self.username, self.realname))
@@ -104,10 +102,11 @@ class IRCConnection(object):
             self.send("PASS :%s\n" % (self.password,))
     
     def send(self, data):
-        r""" Queues the given data, waiting for the TBB to give it a go.
+        """Queues the given data, waiting for the TBB to give it a go.
 
-        Notice that this converts \r and \r\n to just \n.
+        Notice that this converts CR and CRLF to just LF.
         """
+
         for line in data.replace("\r", "").split("\n"):
             if len(line) > 512:
                 raise InvalidIRCData(line)
@@ -116,10 +115,10 @@ class IRCConnection(object):
                 self.out_tbb.append(line + "\n")
 
     def parse(self, line):
-        """ Parse an IRC line.
+        """Parse an IRC line.
             
-            Requires an instance with irc_line_unprefixed and
-            irc_line_prefixed set.
+        Requires an instance with irc_line_unprefixed and
+        irc_line_prefixed set.
         """
 
         prefix = None
@@ -148,21 +147,24 @@ class IRCConnection(object):
         return prefix, command, args
     
     def check_read(self, timeout):
+        """Returns True if there is data waiting."""
+
         r, w, x = select([self.socket], [], [], 0.25)
         return bool(r)
 
     def read(self, bufsize):
-        """ Read at most ``bufsize'' bytes from source. If disconnection
-            occurs, raises Disconnected.
+        """Read at most ``bufsize'' bytes from source. If disconnection
+        occurs, raises Disconnected.
         """
+
         recv = self.socket.recv(bufsize)
         if not recv:
             raise Disconnected()
         return recv
 
     def process_once(self, given_time=0.25):
-        """ Reads any available data, waiting ``given_time'' seconds before
-            returning if no data was available. Incomplete lines are buffered.
+        """Reads any available data, waiting ``given_time'' seconds before
+        returning if no data was available. Incomplete lines are buffered.
         """
 
         # Do the tick before so that scheduled data may be sent, and the
@@ -192,9 +194,10 @@ class IRCConnection(object):
                         cls.__dict__[attrname](self, hostmask, arguments)
 
     def process_forever(self):
-        """ Process as long as self.process is True, meaning you can abort
-            execution by setting process to False.
+        """Process as long as self.process is True, meaning you can abort
+        execution by setting process to False.
         """
+
         self.process = True
         while self.process:
             self.process_once()
@@ -204,8 +207,7 @@ class IRCConnection(object):
     debug = debug_print
 
 class CommonIRCConnection(IRCConnection):
-    """ Defines a lot of convenience functions.
-    """
+    """Defines a lot of convenience functions."""
 
     def _generic_target(self, command, target, message, split_lines=False):
         if split_lines:
